import React from 'react';
import type { SxProps } from '@mui/material';
import type { ButtonProps as MButtonProps } from '@mui/material/Button';
import { type IconName, type IconSize } from '../Icon';
declare enum EButtonSize {
    XL = "xl",
    L = "l",
    M = "m",
    S = "s"
}
type ButtonIconName = IconName;
declare enum EButtonVariants {
    PRIMARY = "primary",
    SECONDARY = "secondary",
    GHOST = "ghost",
    TEXT = "text",
    COLOR = "color"
}
declare enum EButtonColors {
    ERROR = "error",
    INFO = "info",
    SUCCESS = "success",
    WARNING = "warning",
    ELEVATION_0 = "elevation0",
    ELEVATION_1 = "elevation1",
    ELEVATION_2 = "elevation2",
    ELEVATION_3 = "elevation3",
    ON_BRAND = "onBrand",
    BRAND = "brand",
    BLUE_ELEVATION_1 = "blueElevation1",
    BLUE_ELEVATION_2 = "blueElevation2",
    SPECIAL = "special",
    STATUS1 = "status1",
    STATUS2 = "status2",
    STATUS3 = "status3",
    STATUS4 = "status4",
    STATUS5 = "status5"
}
interface IDefaultButtonSize {
    variant: EButtonVariants.PRIMARY | EButtonVariants.SECONDARY | EButtonVariants.GHOST | EButtonVariants.COLOR;
    size: EButtonSize.XL | EButtonSize.L | EButtonSize.M | EButtonSize.S;
}
interface ITextButtonSize {
    variant: EButtonVariants.TEXT;
    size?: EButtonSize.M | EButtonSize.S;
}
type ExcludeButtonProps = 'style' | 'sx' | 'class' | 'variant' | 'color' | 'size';
type ButtonProps = Omit<MButtonProps, ExcludeButtonProps> & {
    variant?: IDefaultButtonSize['variant'] | ITextButtonSize['variant'];
    color?: EButtonColors;
    size?: IDefaultButtonSize['size'] | ITextButtonSize['size'];
    caps?: boolean;
    iconSize?: IconSize;
    startIcon?: IconName;
    endIcon?: IconName;
    loading?: boolean;
    onBrand?: boolean;
    disabled?: boolean;
    noHover?: boolean;
    deprecatedSX?: SxProps;
};
declare const Button: React.ForwardRefExoticComponent<Omit<ButtonProps, "ref"> & React.RefAttributes<HTMLButtonElement>>;
export default Button;
export { EButtonSize, IconSize, EButtonVariants, EButtonColors };
export type { ButtonProps, ButtonIconName };
